aboutsummaryrefslogtreecommitdiffstats
path: root/phpBB/phpbb/extension
diff options
context:
space:
mode:
Diffstat (limited to 'phpBB/phpbb/extension')
-rw-r--r--phpBB/phpbb/extension/base.php6
-rw-r--r--phpBB/phpbb/extension/finder.php532
-rw-r--r--phpBB/phpbb/extension/manager.php43
-rw-r--r--phpBB/phpbb/extension/metadata_manager.php115
-rw-r--r--phpBB/phpbb/extension/provider.php2
5 files changed, 95 insertions, 603 deletions
diff --git a/phpBB/phpbb/extension/base.php b/phpBB/phpbb/extension/base.php
index eb306aeb72..cbbd7bc622 100644
--- a/phpBB/phpbb/extension/base.php
+++ b/phpBB/phpbb/extension/base.php
@@ -23,7 +23,7 @@ class base implements \phpbb\extension\extension_interface
/** @var ContainerInterface */
protected $container;
- /** @var \phpbb\extension\finder */
+ /** @var \phpbb\finder */
protected $finder;
/** @var \phpbb\db\migrator */
@@ -39,11 +39,11 @@ class base implements \phpbb\extension\extension_interface
* Constructor
*
* @param ContainerInterface $container Container object
- * @param \phpbb\extension\finder $extension_finder
+ * @param \phpbb\finder $extension_finder
* @param string $extension_name Name of this extension (from ext.manager)
* @param string $extension_path Relative path to this extension
*/
- public function __construct(ContainerInterface $container, \phpbb\extension\finder $extension_finder, \phpbb\db\migrator $migrator, $extension_name, $extension_path)
+ public function __construct(ContainerInterface $container, \phpbb\finder $extension_finder, \phpbb\db\migrator $migrator, $extension_name, $extension_path)
{
$this->container = $container;
$this->extension_finder = $extension_finder;
diff --git a/phpBB/phpbb/extension/finder.php b/phpBB/phpbb/extension/finder.php
deleted file mode 100644
index 71a5542b67..0000000000
--- a/phpBB/phpbb/extension/finder.php
+++ /dev/null
@@ -1,532 +0,0 @@
-<?php
-/**
-*
-* This file is part of the phpBB Forum Software package.
-*
-* @copyright (c) phpBB Limited <https://www.phpbb.com>
-* @license GNU General Public License, version 2 (GPL-2.0)
-*
-* For full copyright and license information, please see
-* the docs/CREDITS.txt file.
-*
-*/
-
-namespace phpbb\extension;
-
-/**
-* The extension finder provides a simple way to locate files in active extensions
-*/
-class finder
-{
- protected $extension_manager;
- protected $filesystem;
- protected $phpbb_root_path;
- protected $cache;
- protected $php_ext;
-
- /**
- * The cache variable name used to store $this->cached_queries in $this->cache.
- *
- * Allows the use of multiple differently configured finders with the same cache.
- * @var string
- */
- protected $cache_name;
-
- /**
- * An associative array, containing all search parameters set in methods.
- * @var array
- */
- protected $query;
-
- /**
- * A map from md5 hashes of serialized queries to their previously retrieved
- * results.
- * @var array
- */
- protected $cached_queries;
-
- /**
- * Creates a new finder instance with its dependencies
- *
- * @param \phpbb\extension\manager $extension_manager An extension manager
- * instance that provides the finder with a list of active
- * extensions and their locations
- * @param \phpbb\filesystem $filesystem Filesystem instance
- * @param string $phpbb_root_path Path to the phpbb root directory
- * @param \phpbb\cache\driver\driver_interface $cache A cache instance or null
- * @param string $php_ext php file extension
- * @param string $cache_name The name of the cache variable, defaults to
- * _ext_finder
- */
- public function __construct(\phpbb\extension\manager $extension_manager, \phpbb\filesystem $filesystem, $phpbb_root_path = '', \phpbb\cache\driver\driver_interface $cache = null, $php_ext = 'php', $cache_name = '_ext_finder')
- {
- $this->extension_manager = $extension_manager;
- $this->filesystem = $filesystem;
- $this->phpbb_root_path = $phpbb_root_path;
- $this->cache = $cache;
- $this->php_ext = $php_ext;
- $this->cache_name = $cache_name;
-
- $this->query = array(
- 'core_path' => false,
- 'core_suffix' => false,
- 'core_prefix' => false,
- 'core_directory' => false,
- 'extension_suffix' => false,
- 'extension_prefix' => false,
- 'extension_directory' => false,
- );
-
- $this->cached_queries = ($this->cache) ? $this->cache->get($this->cache_name) : false;
- }
-
- /**
- * Sets a core path to be searched in addition to extensions
- *
- * @param string $core_path The path relative to phpbb_root_path
- * @return \phpbb\extension\finder This object for chaining calls
- */
- public function core_path($core_path)
- {
- $this->query['core_path'] = $core_path;
- return $this;
- }
-
- /**
- * Sets the suffix all files found in extensions and core must match.
- *
- * There is no default file extension, so to find PHP files only, you will
- * have to specify .php as a suffix. However when using get_classes, the .php
- * file extension is automatically added to suffixes.
- *
- * @param string $suffix A filename suffix
- * @return \phpbb\extension\finder This object for chaining calls
- */
- public function suffix($suffix)
- {
- $this->core_suffix($suffix);
- $this->extension_suffix($suffix);
- return $this;
- }
-
- /**
- * Sets a suffix all files found in extensions must match
- *
- * There is no default file extension, so to find PHP files only, you will
- * have to specify .php as a suffix. However when using get_classes, the .php
- * file extension is automatically added to suffixes.
- *
- * @param string $extension_suffix A filename suffix
- * @return \phpbb\extension\finder This object for chaining calls
- */
- public function extension_suffix($extension_suffix)
- {
- $this->query['extension_suffix'] = $extension_suffix;
- return $this;
- }
-
- /**
- * Sets a suffix all files found in the core path must match
- *
- * There is no default file extension, so to find PHP files only, you will
- * have to specify .php as a suffix. However when using get_classes, the .php
- * file extension is automatically added to suffixes.
- *
- * @param string $core_suffix A filename suffix
- * @return \phpbb\extension\finder This object for chaining calls
- */
- public function core_suffix($core_suffix)
- {
- $this->query['core_suffix'] = $core_suffix;
- return $this;
- }
-
- /**
- * Sets the prefix all files found in extensions and core must match
- *
- * @param string $prefix A filename prefix
- * @return \phpbb\extension\finder This object for chaining calls
- */
- public function prefix($prefix)
- {
- $this->core_prefix($prefix);
- $this->extension_prefix($prefix);
- return $this;
- }
-
- /**
- * Sets a prefix all files found in extensions must match
- *
- * @param string $extension_prefix A filename prefix
- * @return \phpbb\extension\finder This object for chaining calls
- */
- public function extension_prefix($extension_prefix)
- {
- $this->query['extension_prefix'] = $extension_prefix;
- return $this;
- }
-
- /**
- * Sets a prefix all files found in the core path must match
- *
- * @param string $core_prefix A filename prefix
- * @return \phpbb\extension\finder This object for chaining calls
- */
- public function core_prefix($core_prefix)
- {
- $this->query['core_prefix'] = $core_prefix;
- return $this;
- }
-
- /**
- * Sets a directory all files found in extensions and core must be contained in
- *
- * Automatically sets the core_directory if its value does not differ from
- * the current directory.
- *
- * @param string $directory
- * @return \phpbb\extension\finder This object for chaining calls
- */
- public function directory($directory)
- {
- $this->core_directory($directory);
- $this->extension_directory($directory);
- return $this;
- }
-
- /**
- * Sets a directory all files found in extensions must be contained in
- *
- * @param string $extension_directory
- * @return \phpbb\extension\finder This object for chaining calls
- */
- public function extension_directory($extension_directory)
- {
- $this->query['extension_directory'] = $this->sanitise_directory($extension_directory);
- return $this;
- }
-
- /**
- * Sets a directory all files found in the core path must be contained in
- *
- * @param string $core_directory
- * @return \phpbb\extension\finder This object for chaining calls
- */
- public function core_directory($core_directory)
- {
- $this->query['core_directory'] = $this->sanitise_directory($core_directory);
- return $this;
- }
-
- /**
- * Removes occurances of /./ and makes sure path ends without trailing slash
- *
- * @param string $directory A directory pattern
- * @return string A cleaned up directory pattern
- */
- protected function sanitise_directory($directory)
- {
- $directory = $this->filesystem->clean_path($directory);
- $dir_len = strlen($directory);
-
- if ($dir_len > 1 && $directory[$dir_len - 1] === '/')
- {
- $directory = substr($directory, 0, -1);
- }
-
- return $directory;
- }
-
- /**
- * Finds classes matching the configured options if they follow phpBB naming rules.
- *
- * The php file extension is automatically added to suffixes.
- *
- * Note: If a file is matched but contains a class name not following the
- * phpBB naming rules an incorrect class name will be returned.
- *
- * @param bool $cache Whether the result should be cached
- * @param bool $use_all_available Use all available instead of just all
- * enabled extensions
- * @return array An array of found class names
- */
- public function get_classes($cache = true, $use_all_available = false)
- {
- $this->query['extension_suffix'] .= '.' . $this->php_ext;
- $this->query['core_suffix'] .= '.' . $this->php_ext;
-
- $files = $this->find($cache, false, $use_all_available);
-
- return $this->get_classes_from_files($files);
- }
-
- /**
- * Get class names from a list of files
- *
- * @param array $files Array of files (from find())
- * @return array Array of class names
- */
- public function get_classes_from_files($files)
- {
- $classes = array();
- foreach ($files as $file => $ext_name)
- {
- $class = substr($file, 0, -strlen('.' . $this->php_ext));
- if ($ext_name === '/' && preg_match('#^includes/#', $file))
- {
- $class = preg_replace('#^includes/#', '', $class);
- $classes[] = 'phpbb_' . str_replace('/', '_', $class);
- }
- else
- {
- $class = preg_replace('#^ext/#', '', $class);
- $classes[] = '\\' . str_replace('/', '\\', $class);
- }
- }
- return $classes;
- }
-
- /**
- * Finds all directories matching the configured options
- *
- * @param bool $cache Whether the result should be cached
- * @param bool $use_all_available Use all available instead of just all
- * enabled extensions
- * @param bool $extension_keys Whether the result should have extension name as array key
- * @return array An array of paths to found directories
- */
- public function get_directories($cache = true, $use_all_available = false, $extension_keys = false)
- {
- return $this->find_with_root_path($cache, true, $use_all_available, $extension_keys);
- }
-
- /**
- * Finds all files matching the configured options.
- *
- * @param bool $cache Whether the result should be cached
- * @param bool $use_all_available Use all available instead of just all
- * enabled extensions
- * @return array An array of paths to found files
- */
- public function get_files($cache = true, $use_all_available = false)
- {
- return $this->find_with_root_path($cache, false, $use_all_available);
- }
-
- /**
- * A wrapper around the general find which prepends a root path to results
- *
- * @param bool $cache Whether the result should be cached
- * @param bool $is_dir Directories will be returned when true, only files
- * otherwise
- * @param bool $use_all_available Use all available instead of just all
- * enabled extensions
- * @param bool $extension_keys If true, result will be associative array
- * with extension name as key
- * @return array An array of paths to found items
- */
- protected function find_with_root_path($cache = true, $is_dir = false, $use_all_available = false, $extension_keys = false)
- {
- $items = $this->find($cache, $is_dir, $use_all_available);
-
- $result = array();
- foreach ($items as $item => $ext_name)
- {
- if ($extension_keys)
- {
- $result[$ext_name] = $this->phpbb_root_path . $item;
- }
- else
- {
- $result[] = $this->phpbb_root_path . $item;
- }
- }
-
- return $result;
- }
-
- /**
- * Finds all file system entries matching the configured options
- *
- * @param bool $cache Whether the result should be cached
- * @param bool $is_dir Directories will be returned when true, only files
- * otherwise
- * @param bool $use_all_available Use all available instead of just all
- * enabled extensions
- * @return array An array of paths to found items
- */
- public function find($cache = true, $is_dir = false, $use_all_available = false)
- {
- if ($use_all_available)
- {
- $extensions = $this->extension_manager->all_available();
- }
- else
- {
- $extensions = $this->extension_manager->all_enabled();
- }
-
- if ($this->query['core_path'])
- {
- $extensions['/'] = $this->phpbb_root_path . $this->query['core_path'];
- }
-
- $files = array();
- $file_list = $this->find_from_paths($extensions, $cache, $is_dir);
-
- foreach ($file_list as $file)
- {
- $files[$file['named_path']] = $file['ext_name'];
- }
-
- return $files;
- }
-
- /**
- * Finds all file system entries matching the configured options for one
- * specific extension
- *
- * @param string $extension_name Name of the extension
- * @param string $extension_path Relative path to the extension root directory
- * @param bool $cache Whether the result should be cached
- * @param bool $is_dir Directories will be returned when true, only files
- * otherwise
- * @return array An array of paths to found items
- */
- public function find_from_extension($extension_name, $extension_path, $cache = true, $is_dir = false)
- {
- $extensions = array(
- $extension_name => $extension_path,
- );
-
- $files = array();
- $file_list = $this->find_from_paths($extensions, $cache, $is_dir);
-
- foreach ($file_list as $file)
- {
- $files[$file['named_path']] = $file['ext_name'];
- }
-
- return $files;
- }
-
- /**
- * Finds all file system entries matching the configured options from
- * an array of paths
- *
- * @param array $extensions Array of extensions (name => full relative path)
- * @param bool $cache Whether the result should be cached
- * @param bool $is_dir Directories will be returned when true, only files
- * otherwise
- * @return array An array of paths to found items
- */
- public function find_from_paths($extensions, $cache = true, $is_dir = false)
- {
- $this->query['is_dir'] = $is_dir;
- $query = md5(serialize($this->query) . serialize($extensions));
-
- if (!defined('DEBUG') && $cache && isset($this->cached_queries[$query]))
- {
- return $this->cached_queries[$query];
- }
-
- $files = array();
-
- foreach ($extensions as $name => $path)
- {
- $ext_name = $name;
-
- if (!file_exists($path))
- {
- continue;
- }
-
- if ($name === '/')
- {
- $location = $this->query['core_path'];
- $name = '';
- $suffix = $this->query['core_suffix'];
- $prefix = $this->query['core_prefix'];
- $directory = $this->query['core_directory'];
- }
- else
- {
- $location = 'ext/';
- $name .= '/';
- $suffix = $this->query['extension_suffix'];
- $prefix = $this->query['extension_prefix'];
- $directory = $this->query['extension_directory'];
- }
-
- // match only first directory if leading slash is given
- if ($directory === '/')
- {
- $directory_pattern = '^' . preg_quote(DIRECTORY_SEPARATOR, '#');
- }
- else if ($directory && $directory[0] === '/')
- {
- $directory_pattern = '^' . preg_quote(str_replace('/', DIRECTORY_SEPARATOR, $directory) . DIRECTORY_SEPARATOR, '#');
- }
- else
- {
- $directory_pattern = preg_quote(DIRECTORY_SEPARATOR . str_replace('/', DIRECTORY_SEPARATOR, $directory) . DIRECTORY_SEPARATOR, '#');
- }
- if ($is_dir)
- {
- $directory_pattern .= '$';
- }
- $directory_pattern = '#' . $directory_pattern . '#';
-
- $iterator = new \RecursiveIteratorIterator(
- new \phpbb\recursive_dot_prefix_filter_iterator(
- new \RecursiveDirectoryIterator(
- $path,
- \FilesystemIterator::SKIP_DOTS
- )
- ),
- \RecursiveIteratorIterator::SELF_FIRST
- );
-
- foreach ($iterator as $file_info)
- {
- $filename = $file_info->getFilename();
-
- if ($file_info->isDir() == $is_dir)
- {
- if ($is_dir)
- {
- $relative_path = $iterator->getInnerIterator()->getSubPath() . DIRECTORY_SEPARATOR . basename($filename) . DIRECTORY_SEPARATOR;
- if ($relative_path[0] !== DIRECTORY_SEPARATOR)
- {
- $relative_path = DIRECTORY_SEPARATOR . $relative_path;
- }
- }
- else
- {
- $relative_path = DIRECTORY_SEPARATOR . $iterator->getInnerIterator()->getSubPathname();
- }
-
- if ((!$suffix || substr($relative_path, -strlen($suffix)) === $suffix) &&
- (!$prefix || substr($filename, 0, strlen($prefix)) === $prefix) &&
- (!$directory || preg_match($directory_pattern, $relative_path)))
- {
- $files[] = array(
- 'named_path' => str_replace(DIRECTORY_SEPARATOR, '/', $location . $name . substr($relative_path, 1)),
- 'ext_name' => $ext_name,
- 'path' => str_replace(array(DIRECTORY_SEPARATOR, $this->phpbb_root_path), array('/', ''), $file_info->getPath()) . '/',
- 'filename' => $filename,
- );
- }
- }
- }
- }
-
- if ($cache && $this->cache)
- {
- $this->cached_queries[$query] = $files;
- $this->cache->put($this->cache_name, $this->cached_queries);
- }
-
- return $files;
- }
-}
diff --git a/phpBB/phpbb/extension/manager.php b/phpBB/phpbb/extension/manager.php
index 0bfec23573..4130e8455a 100644
--- a/phpBB/phpbb/extension/manager.php
+++ b/phpBB/phpbb/extension/manager.php
@@ -26,6 +26,7 @@ class manager
protected $db;
protected $config;
protected $cache;
+ protected $user;
protected $php_ext;
protected $extensions;
protected $extension_table;
@@ -37,25 +38,27 @@ class manager
*
* @param ContainerInterface $container A container
* @param \phpbb\db\driver\driver_interface $db A database connection
- * @param \phpbb\config\config $config \phpbb\config\config
+ * @param \phpbb\config\config $config Config object
* @param \phpbb\filesystem $filesystem
+ * @param \phpbb\user $user User object
* @param string $extension_table The name of the table holding extensions
* @param string $phpbb_root_path Path to the phpbb includes directory.
- * @param string $php_ext php file extension
+ * @param string $php_ext php file extension, defaults to php
* @param \phpbb\cache\driver\driver_interface $cache A cache instance or null
* @param string $cache_name The name of the cache variable, defaults to _ext
*/
- public function __construct(ContainerInterface $container, \phpbb\db\driver\driver_interface $db, \phpbb\config\config $config, \phpbb\filesystem $filesystem, $extension_table, $phpbb_root_path, $php_ext = 'php', \phpbb\cache\driver\driver_interface $cache = null, $cache_name = '_ext')
+ public function __construct(ContainerInterface $container, \phpbb\db\driver\driver_interface $db, \phpbb\config\config $config, \phpbb\filesystem $filesystem, \phpbb\user $user, $extension_table, $phpbb_root_path, $php_ext = 'php', \phpbb\cache\driver\driver_interface $cache = null, $cache_name = '_ext')
{
+ $this->cache = $cache;
+ $this->cache_name = $cache_name;
+ $this->config = $config;
$this->container = $container;
- $this->phpbb_root_path = $phpbb_root_path;
$this->db = $db;
- $this->config = $config;
- $this->cache = $cache;
+ $this->extension_table = $extension_table;
$this->filesystem = $filesystem;
+ $this->phpbb_root_path = $phpbb_root_path;
$this->php_ext = $php_ext;
- $this->extension_table = $extension_table;
- $this->cache_name = $cache_name;
+ $this->user = $user;
$this->extensions = ($this->cache) ? $this->cache->get($this->cache_name) : false;
@@ -145,12 +148,12 @@ class manager
* Instantiates the metadata manager for the extension with the given name
*
* @param string $name The extension name
- * @param string $template The template manager
+ * @param \phpbb\template\template $template The template manager
* @return \phpbb\extension\metadata_manager Instance of the metadata manager
*/
public function create_extension_metadata_manager($name, \phpbb\template\template $template)
{
- return new \phpbb\extension\metadata_manager($name, $this->config, $this, $template, $this->phpbb_root_path);
+ return new \phpbb\extension\metadata_manager($name, $this->config, $this, $template, $this->user, $this->phpbb_root_path);
}
/**
@@ -420,7 +423,7 @@ class manager
foreach ($iterator as $file_info)
{
- if ($file_info->isFile() && $file_info->getFilename() == 'ext.' . $this->php_ext)
+ if ($file_info->isFile() && $file_info->getFilename() == 'composer.json')
{
$ext_name = $iterator->getInnerIterator()->getSubPath();
$composer_file = $iterator->getPath() . '/composer.json';
@@ -529,12 +532,22 @@ class manager
}
/**
- * Instantiates a \phpbb\extension\finder.
+ * Instantiates a \phpbb\finder.
*
- * @return \phpbb\extension\finder An extension finder instance
+ * @param bool $use_all_available Should we load all extensions, or just enabled ones
+ * @return \phpbb\finder An extension finder instance
*/
- public function get_finder()
+ public function get_finder($use_all_available = false)
{
- return new \phpbb\extension\finder($this, $this->filesystem, $this->phpbb_root_path, $this->cache, $this->php_ext, $this->cache_name . '_finder');
+ $finder = new \phpbb\finder($this->filesystem, $this->phpbb_root_path, $this->cache, $this->php_ext, $this->cache_name . '_finder');
+ if ($use_all_available)
+ {
+ $finder->set_extensions(array_keys($this->all_available()));
+ }
+ else
+ {
+ $finder->set_extensions(array_keys($this->all_enabled()));
+ }
+ return $finder;
}
}
diff --git a/phpBB/phpbb/extension/provider.php b/phpBB/phpbb/extension/provider.php
index e1d854df64..1c42cf7b5e 100644
--- a/phpBB/phpbb/extension/provider.php
+++ b/phpBB/phpbb/extension/provider.php
@@ -58,7 +58,7 @@ abstract class provider implements \IteratorAggregate
/**
* Retrieve an iterator over all items
*
- * @return ArrayIterator An iterator for the array of template paths
+ * @return \ArrayIterator An iterator for the array of template paths
*/
public function getIterator()
{
diff --git a/phpBB/phpbb/extension/metadata_manager.php b/phpBB/phpbb/extension/metadata_manager.php
index 047f0ca54c..014d8c79c7 100644
--- a/phpBB/phpbb/extension/metadata_manager.php
+++ b/phpBB/phpbb/extension/metadata_manager.php
@@ -37,6 +37,12 @@ class metadata_manager
protected $template;
/**
+ * phpBB User instance
+ * @var \phpbb\user
+ */
+ protected $user;
+
+ /**
* phpBB root path
* @var string
*/
@@ -65,15 +71,17 @@ class metadata_manager
*
* @param string $ext_name Name (including vendor) of the extension
* @param \phpbb\config\config $config phpBB Config instance
* @param \phpbb\extension\manager $extension_manager An instance of the phpBBb extension manager
* @param \phpbb\template\template $template phpBB Template instance
* @param string $phpbb_root_path Path to the phpbb includes directory.
*/
- public function __construct($ext_name, \phpbb\config\config $config, \phpbb\extension\manager $extension_manager, \phpbb\template\template $template, $phpbb_root_path)
+ public function __construct($ext_name, \phpbb\config\config $config, \phpbb\extension\manager $extension_manager, \phpbb\template\template $template, \phpbb\user $user, $phpbb_root_path)
{
$this->config = $config;
$this->extension_manager = $extension_manager;
$this->template = $template;
+ $this->user = $user;
$this->phpbb_root_path = $phpbb_root_path;
$this->ext_name = $ext_name;
@@ -82,11 +90,11 @@ class metadata_manager
}
/**
- * Processes and gets the metadata requested
- *
- * @param string $element All for all metadata that it has and is valid, otherwise specify which section you want by its shorthand term.
- * @return array Contains all of the requested metadata, throws an exception on failure
- */
+ * Processes and gets the metadata requested
+ *
+ * @param string $element All for all metadata that it has and is valid, otherwise specify which section you want by its shorthand term.
+ * @return array Contains all of the requested metadata, throws an exception on failure
+ */
public function get_metadata($element = 'all')
{
$this->set_metadata_file();
@@ -128,10 +136,10 @@ class metadata_manager
}
/**
- * Sets the filepath of the metadata file
- *
- * @return boolean Set to true if it exists, throws an exception on failure
- */
+ * Sets the filepath of the metadata file
+ *
+ * @throws \phpbb\extension\exception
+ */
private function set_metadata_file()
{
$ext_filepath = $this->extension_manager->get_extension_path($this->ext_name);
@@ -141,31 +149,32 @@ class metadata_manager
if (!file_exists($this->metadata_file))
{
- throw new \phpbb\extension\exception('The required file does not exist: ' . $this->metadata_file);
+ throw new \phpbb\extension\exception($this->user->lang('FILE_NOT_FOUND', $this->metadata_file));
}
}
/**
- * Gets the contents of the composer.json file
- *
- * @return bool True if success, throws an exception on failure
- */
+ * Gets the contents of the composer.json file
+ *
+ * @return bool True if success, throws an exception on failure
+ * @throws \phpbb\extension\exception
+ */
private function fetch_metadata()
{
if (!file_exists($this->metadata_file))
{
- throw new \phpbb\extension\exception('The required file does not exist: ' . $this->metadata_file);
+ throw new \phpbb\extension\exception($this->user->lang('FILE_NOT_FOUND', $this->metadata_file));
}
else
{
if (!($file_contents = file_get_contents($this->metadata_file)))
{
- throw new \phpbb\extension\exception('file_get_contents failed on ' . $this->metadata_file);
+ throw new \phpbb\extension\exception($this->user->lang('FILE_CONTENT_ERR', $this->metadata_file));
}
if (($metadata = json_decode($file_contents, true)) === null)
{
- throw new \phpbb\extension\exception('json_decode failed on ' . $this->metadata_file);
+ throw new \phpbb\extension\exception($this->user->lang('FILE_JSON_DECODE_ERR', $this->metadata_file));
}
$this->metadata = $metadata;
@@ -175,10 +184,10 @@ class metadata_manager
}
/**
- * This array handles the cleaning of the array
- *
- * @return array Contains the cleaned metadata array
- */
+ * This array handles the cleaning of the array
+ *
+ * @return array Contains the cleaned metadata array
+ */
private function clean_metadata_array()
{
return $this->metadata;
@@ -191,6 +200,7 @@ class metadata_manager
* "display" for name, type, and authors
* "name", "type")
* @return Bool True if valid, throws an exception if invalid
+ * @throws \phpbb\extension\exception
*/
public function validate($name = 'display')
{
@@ -224,12 +234,12 @@ class metadata_manager
{
if (!isset($this->metadata[$name]))
{
- throw new \phpbb\extension\exception("Required meta field '$name' has not been set.");
+ throw new \phpbb\extension\exception($this->user->lang('META_FIELD_NOT_SET', $name));
}
if (!preg_match($fields[$name], $this->metadata[$name]))
{
- throw new \phpbb\extension\exception("Meta field '$name' is invalid.");
+ throw new \phpbb\extension\exception($this->user->lang('META_FIELD_INVALID', $name));
}
}
break;
@@ -239,22 +249,23 @@ class metadata_manager
}
/**
- * Validates the contents of the authors field
- *
- * @return boolean True when passes validation, throws exception if invalid
- */
+ * Validates the contents of the authors field
+ *
+ * @return boolean True when passes validation, throws exception if invalid
+ * @throws \phpbb\extension\exception
+ */
public function validate_authors()
{
if (empty($this->metadata['authors']))
{
- throw new \phpbb\extension\exception("Required meta field 'authors' has not been set.");
+ throw new \phpbb\extension\exception($this->user->lang('META_FIELD_NOT_SET', 'authors'));
}
foreach ($this->metadata['authors'] as $author)
{
if (!isset($author['name']))
{
- throw new \phpbb\extension\exception("Required meta field 'author name' has not been set.");
+ throw new \phpbb\extension\exception($this->user->lang('META_FIELD_NOT_SET', 'author name'));
}
}
@@ -262,10 +273,10 @@ class metadata_manager
}
/**
- * This array handles the verification that this extension can be enabled on this board
- *
- * @return bool True if validation succeeded, False if failed
- */
+ * This array handles the verification that this extension can be enabled on this board
+ *
+ * @return bool True if validation succeeded, False if failed
+ */
public function validate_enable()
{
// Check for valid directory & phpBB, PHP versions
@@ -278,10 +289,10 @@ class metadata_manager
}
/**
- * Validates the most basic directory structure to ensure it follows <vendor>/<ext> convention.
- *
- * @return boolean True when passes validation
- */
+ * Validates the most basic directory structure to ensure it follows <vendor>/<ext> convention.
+ *
+ * @return boolean True when passes validation
+ */
public function validate_dir()
{
return (substr_count($this->ext_name, '/') === 1 && $this->ext_name == $this->get_metadata('name'));
@@ -289,10 +300,10 @@ class metadata_manager
/**
- * Validates the contents of the phpbb requirement field
- *
- * @return boolean True when passes validation
- */
+ * Validates the contents of the phpbb requirement field
+ *
+ * @return boolean True when passes validation
+ */
public function validate_require_phpbb()
{
if (!isset($this->metadata['require']['phpbb/phpbb']))
@@ -304,10 +315,10 @@ class metadata_manager
}
/**
- * Validates the contents of the php requirement field
- *
- * @return boolean True when passes validation
- */
+ * Validates the contents of the php requirement field
+ *
+ * @return boolean True when passes validation
+ */
public function validate_require_php()
{
if (!isset($this->metadata['require']['php']))
@@ -340,10 +351,10 @@ class metadata_manager
}
/**
- * Outputs the metadata into the template
- *
- * @return null
- */
+ * Outputs the metadata into the template
+ *
+ * @return null
+ */
public function output_template_data()
{
$this->template->assign_vars(array(
@@ -65,15 +71,17 @@ class metadata_manager
* @param string $ext_name Name (including vendor) of the extension
* @param \phpbb\config\config $config phpBB Config instance
- * @param \phpbb\extension\manager $extension_manager An instance of the phpBBb extension manager
- * @param \phpbb\template\template $template phpBB Template instance
+ * @param \phpbb\extension\manager $extension_manager An instance of the phpBB extension manager
+ * @param \phpbb\template\template $template phpBB Template instance
+ * @param \phpbb\user $user User instance
* @param string $phpbb_root_path Path to the phpbb includes directory.
*/